pub unsafe trait KernelArgumentList<const ARGC: usize> {
// Required method
unsafe fn as_raw_arg_list(&self) -> [&[u8]; ARGC];
}Expand description
Types which describe an argument list for a SYCL kernel.
Safety: a type implement this trait must mirror the representation and alignment of each corresponding SYCL kernel argument inside the returned array.
Required Methods
Sourceunsafe fn as_raw_arg_list(&self) -> [&[u8]; ARGC]
unsafe fn as_raw_arg_list(&self) -> [&[u8]; ARGC]
Converts each struct member to a raw byte representation.
Safety: This function returns references to raw bytes. These bytes will be passed to FFI functions. The caller must make sure these functions respect Rust’s aliasing rules.